networkx\_algo\_common\_subtree.balanced\_embedding module
==========================================================

.. automodule:: networkx_algo_common_subtree.balanced_embedding
   :members:
   :undoc-members:
   :show-inheritance:
